.. _utilipy-utils-inspect:

*********************************
Inspect (`utilipy.utils.inspect`)
*********************************

.. currentmodule:: utilipy.utils.inspect


Reference/API
=============

.. automodapi:: utilipy.utils.inspect
